==> billiards-0.1.tar.gz: billiards-0.1/src/pack.c <==
/* Copyright (C) 2008 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <lua.h>
#include <lauxlib.h>

#define UNPACK(type)				\
    {						\
	int i, n;				\
	type *data;				\
						\
	luaL_checkstring (L, 1);		\
	lua_newtable (L);			\
						\
	data = (type *)lua_tostring(L, 1);		\
	n = lua_strlen (L, 1) / sizeof (type);		\
							\
	for (i = 0 ; i < n ; i += 1) {			\
	    lua_pushnumber (L, data[i]);		\
	    lua_rawseti (L, 2, i + 1);			\
	}						\
    }

static int unpackfloats(lua_State *L)
{
    UNPACK(float);
    
    return 1;
}

static int unpackushorts(lua_State *L)
{
    UNPACK(unsigned short);
    
    return 1;
}

static int unpackshorts(lua_State *L)
{
    UNPACK(short);
    
    return 1;
}

static int unpackints(lua_State *L)
{
    UNPACK(int);
    
    return 1;
}

static int unpackuints(lua_State *L)
{
    UNPACK(unsigned int);
    
    return 1;
}

static int unpackbytes(lua_State *L)
{
    UNPACK(char);
    
    return 1;
}

static int unpackubytes(lua_State *L)
{
    UNPACK(unsigned char);
    
    return 1;
}

int luaopen_pack (lua_State *L)
{
    const luaL_Reg pack[] = {
	{"fromfloats", unpackfloats},
	{"fromshorts", unpackshorts},
	{"fromunsignedshorts", unpackushorts},
	{"fromints", unpackints},
	{"fromunsignedints", unpackuints},
	{"frombytes", unpackbytes},
	{"fromunsignedbytes", unpackubytes},
	{NULL, NULL}
    };

    luaL_register (L, "pack", pack);

    return 0;
}

==> billiards-0.2.tar.gz: billiards-0.2/src/pack.c <==
/* Copyright (C) 2008 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <lua.h>
#include <lauxlib.h>

#define UNPACK(type)				\
    {						\
	int i, n;				\
	type *data;				\
						\
	luaL_checkstring (_L, 1);		\
	lua_newtable (_L);			\
						\
	data = (type *)lua_tostring (_L, 1);		\
	n = lua_strlen (_L, 1) / sizeof (type);		\
							\
	for (i = 0 ; i < n ; i += 1) {			\
	    lua_pushnumber (_L, data[i]);		\
	    lua_rawseti (_L, 2, i + 1);			\
	}						\
    }

static int unpackfloats(lua_State *L)
{
    UNPACK(float);
    
    return 1;
}

static int unpackushorts(lua_State *L)
{
    UNPACK(unsigned short);
    
    return 1;
}

static int unpackshorts(lua_State *L)
{
    UNPACK(short);
    
    return 1;
}

static int unpackints(lua_State *L)
{
    UNPACK(int);
    
    return 1;
}

static int unpackuints(lua_State *L)
{
    UNPACK(unsigned int);
    
    return 1;
}

static int unpackbytes(lua_State *L)
{
    UNPACK(char);
    
    return 1;
}

static int unpackubytes(lua_State *L)
{
    UNPACK(unsigned char);
    
    return 1;
}

int luaopen_pack (lua_State *L)
{
    const luaL_Reg pack[] = {
	{"fromfloats", unpackfloats},
	{"fromshorts", unpackshorts},
	{"fromunsignedshorts", unpackushorts},
	{"fromints", unpackints},
	{"fromunsignedints", unpackuints},
	{"frombytes", unpackbytes},
	{"fromunsignedbytes", unpackubytes},
	{NULL, NULL}
    };

    luaL_register (L, "pack", pack);

    return 0;
}
